@@ -163,7 +163,6 @@ INSTALLED_APPS = [
     "simmate.website.core_components.apps.CoreComponentsConfig",
     "simmate.website.third_parties.apps.ThirdPartyConfig",
     "simmate.website.workflows.apps.WorkflowsConfig",
-    "simmate.website.workflow_execution.apps.WorkflowExecutionConfig",
     #
     # These are built-in django apps that we use for extra features
     "django.contrib.admin",
@@ -427,3 +426,9 @@ LOGIN_REDIRECT_URL = "/accounts/profile/"  # this is already the default
 LOGOUT_REDIRECT_URL = "/accounts/loginstatus/"
 
 # -----------------------------------------------------------------------------
+
+# BUG: To use Django ORM within IPython, Spyder, and Jupyter notebooks, which
+# are examples of async consoles, I need to allow unsafe.
+# Read more at...
+# https://docs.djangoproject.com/en/4.0/topics/async/#async-safety
+os.environ["DJANGO_ALLOW_ASYNC_UNSAFE"] = "true"
